Crate iwrl64xx_pac

Crate iwrl64xx_pac 

Peripheral access API for IWRL6432 microcontrollers (generated using svd2rust v0.33.4 ( ))

You can find an overview of the generated API here.

API features to be included in the next svd2rust release can be generated by cloning the svd2rust repository, checking out the above commit, and running cargo doc --open.

Modules

app_cancfg
APP_CANCFG
app_canecc
APP_CANECC
app_cfg_qspi
APP_CFG_QSPI
app_crc
APP_CRC
app_ctrl
APP_CTRL
app_dcc
APP_DCC
app_ecc_agg
APP_ECC_AGG
app_esm
APP_ESM
app_hwa_adcbuf_ctrl
APP_HWA_ADCBUF_CTRL
app_i2c
APP_I2C
app_lin
APP_LIN
app_prcm
APP_PRCM
app_pwm
APP_PWM
app_rcm
APP_RCM
app_rti
APP_RTI
app_spi_0
APP_SPI
app_spi_1
APP_SPI
app_uart_0
APP_UART
app_uart_1
APP_UART
app_wd
APP_WD
generic
Common register and bit access and modify traits
gpadc_ctrl
GPADC_CTRL
hwa_cfg
HWA_CFG
pbist
PBIST
plldig_ctrl
PLLDIG_CTRL
top_debugss
TOP_DEBUGSS
top_gio
TOP_GIO
top_io_mux
TOP_IO_MUX
topss_ctrl
TOPSS_CTRL
tpcc_a
TPCC
tpcc_b
TPCC
tptc_a0
Register test environment
tptc_a1
Register test environment
tptc_b0
Register test environment
tptc_b0_1
Register test environment

Structs

AppCancfg
APP_CANCFG
AppCanecc
APP_CANECC
AppCfgQspi
APP_CFG_QSPI
AppCrc
APP_CRC
AppCtrl
APP_CTRL
AppDcc
APP_DCC
AppEccAgg
APP_ECC_AGG
AppEsm
APP_ESM
AppHwaAdcbufCtrl
APP_HWA_ADCBUF_CTRL
AppI2c
APP_I2C
AppLin
APP_LIN
AppPrcm
APP_PRCM
AppPwm
APP_PWM
AppRcm
APP_RCM
AppRti
APP_RTI
AppSpi0
APP_SPI
AppSpi1
APP_SPI
AppUart0
APP_UART
AppUart1
APP_UART
AppWd
APP_WD
GpadcCtrl
GPADC_CTRL
HwaCfg
HWA_CFG
Pbist
PBIST
Peripherals
All the peripherals.
PlldigCtrl
PLLDIG_CTRL
TopDebugss
TOP_DEBUGSS
TopGio
TOP_GIO
TopIoMux
TOP_IO_MUX
TopssCtrl
TOPSS_CTRL
TpccA
TPCC
TpccB
TPCC
TptcA0
Register test environment
TptcA1
Register test environment
TptcB0
Register test environment
TptcB0_1
Register test environment

Enums

Interrupt
Enumeration of all the interrupts.

Constants

NVIC_PRIO_BITS
Number available in the NVIC for configuring priority