W

Type Alias W 

pub type W = W<SrcSpec>;
Register SRC writer

Aliased Type

pub struct W { /* private fields */ }

Implementations

Source

impl W

pub fn src(&mut self) -> SrcW<'_, SrcSpec>

Bits 0:31 - 31:0] Source Address: The 32-bit source address parameters specify the starting byte address of the source . If SAM is set to FIFO mode then the user should program the Source address to be aligned to the value specified by the OPT.FWID field. No errors are recognized here but TC will assert error if this is not true.