Peripheral access API for IWRL6432 microcontrollers (generated using svd2rust v0.33.4 ( ))
You can find an overview of the generated API here.
API features to be included in the next
svd2rust release can be generated by cloning the svd2rust repository, checking out the above commit, and running cargo doc --open.
Modules
- app_
cancfg - APP_CANCFG
- app_
canecc - APP_CANECC
- app_
cfg_ qspi - APP_CFG_QSPI
- app_crc
- APP_CRC
- app_
ctrl - APP_CTRL
- app_dcc
- APP_DCC
- app_
ecc_ agg - APP_ECC_AGG
- app_esm
- APP_ESM
- app_
hwa_ adcbuf_ ctrl - APP_HWA_ADCBUF_CTRL
- app_i2c
- APP_I2C
- app_lin
- APP_LIN
- app_
prcm - APP_PRCM
- app_pwm
- APP_PWM
- app_rcm
- APP_RCM
- app_rti
- APP_RTI
- app_
spi_ 0 - APP_SPI
- app_
spi_ 1 - APP_SPI
- app_
uart_ 0 - APP_UART
- app_
uart_ 1 - APP_UART
- app_wd
- APP_WD
- generic
- Common register and bit access and modify traits
- gpadc_
ctrl - GPADC_CTRL
- hwa_cfg
- HWA_CFG
- pbist
- PBIST
- plldig_
ctrl - PLLDIG_CTRL
- top_
debugss - TOP_DEBUGSS
- top_gio
- TOP_GIO
- top_
io_ mux - TOP_IO_MUX
- topss_
ctrl - TOPSS_CTRL
- tpcc_a
- TPCC
- tpcc_b
- TPCC
- tptc_a0
- Register test environment
- tptc_a1
- Register test environment
- tptc_b0
- Register test environment
- tptc_
b0_ 1 - Register test environment
Structs
- AppCancfg
- APP_CANCFG
- AppCanecc
- APP_CANECC
- AppCfg
Qspi - APP_CFG_QSPI
- AppCrc
- APP_CRC
- AppCtrl
- APP_CTRL
- AppDcc
- APP_DCC
- AppEcc
Agg - APP_ECC_AGG
- AppEsm
- APP_ESM
- AppHwa
Adcbuf Ctrl - APP_HWA_ADCBUF_CTRL
- AppI2c
- APP_I2C
- AppLin
- APP_LIN
- AppPrcm
- APP_PRCM
- AppPwm
- APP_PWM
- AppRcm
- APP_RCM
- AppRti
- APP_RTI
- AppSpi0
- APP_SPI
- AppSpi1
- APP_SPI
- AppUart0
- APP_UART
- AppUart1
- APP_UART
- AppWd
- APP_WD
- Gpadc
Ctrl - GPADC_CTRL
- HwaCfg
- HWA_CFG
- Pbist
- PBIST
- Peripherals
- All the peripherals.
- Plldig
Ctrl - PLLDIG_CTRL
- TopDebugss
- TOP_DEBUGSS
- TopGio
- TOP_GIO
- TopIo
Mux - TOP_IO_MUX
- Topss
Ctrl - TOPSS_CTRL
- TpccA
- TPCC
- TpccB
- TPCC
- TptcA0
- Register test environment
- TptcA1
- Register test environment
- TptcB0
- Register test environment
- Tptc
B0_ 1 - Register test environment
Enums
- Interrupt
- Enumeration of all the interrupts.
Constants
- NVIC_
PRIO_ BITS - Number available in the NVIC for configuring priority