SrcW

Type Alias SrcW 

pub type SrcW<'a, REG> = FieldWriter<'a, REG, 32, u32>;
Field SRC writer - 31:0] Source Address: The 32-bit source address parameters specify the starting byte address of the source . If SAM is set to FIFO mode then the user should program the Source address to be aligned to the value specified by the OPT.FWID field. No errors are recognized here but TC will assert error if this is not true.

Aliased Type

pub struct SrcW<'a, REG> { /* private fields */ }